# GRIDOPT: Power Grid Optimization Package

[![Build Status](https://travis-ci.org/ttinoco/GRIDOPT.svg?branch=master)](https://travis-ci.org/ttinoco/GRIDOPT)
[![Documentation Status](https://readthedocs.org/projects/gridopt/badge/?version=latest)](http://gridopt.readthedocs.io/en/latest/?badge=latest)

## Overview

GRIDOPT is a Python package that provides methods for solving power grid optimization problems. Currently, it has the following tools:

* power flow solvers.
* optimal power flow solvers.

## License

BSD 2-clause license.

## Documentation

The documentation for this package can be found in http://gridopt.readthedocs.io/.
